@@ -8,7 +8,7 @@ import osso
 import alarm
 import time
 from portrait import FremantleRotation
-
+import gettext
 
 fhsize = gtk.HILDON_SIZE_FINGER_HEIGHT
 horbtn = hildon.BUTTON_ARRANGEMENT_HORIZONTAL
@@ -20,7 +20,7 @@ class Timer:
         FremantleRotation("Pyrecipe", self.window, '0.3', 0)
 
         self.window.set_default_size(800, 480)
-        self.window.set_title('Pyrecipe - Timer')
+        self.window.set_title(_('Cooking Timer'))
         self.window.connect("delete-event", self.hide_window)
 
         vbox = gtk.VBox()
@@ -39,7 +39,7 @@ class Timer:
             data.append(str(i))
         selector = self.create_selector(data)
         self.hours.set_selector(selector)
-        self.hours.set_title("Hours")
+        self.hours.set_title(_("Hours"))
         self.hours.set_value("0")
 
         self.minutes = hildon.PickerButton(fhsize, horbtn)
@@ -48,7 +48,7 @@ class Timer:
             data.append(str(i))
         selector = self.create_selector(data)
         self.minutes.set_selector(selector)
-        self.minutes.set_title("Minutes")
+        self.minutes.set_title(_("Minutes"))
         self.minutes.set_value("10")
 
         self.seconds = hildon.PickerButton(fhsize, horbtn)
@@ -57,7 +57,7 @@ class Timer:
             data.append(str(i))
         selector = self.create_selector(data)
         self.seconds.set_selector(selector)
-        self.seconds.set_title("Seconds")
+        self.seconds.set_title(_("Seconds"))
         self.seconds.set_value("0")
 
         hbox.pack_start(self.hours, True, True, 0)
@@ -70,24 +70,13 @@ class Timer:
         hbox.set_homogeneous(True)
 
         button = hildon.Button(fhsize, horbtn)
-        button.set_label("Reset")
         img = gtk.Image()
         img.set_from_file(imagesdir + 'reset.png')
         button.set_image(img)
         button.connect('clicked', self.on_reset)
         hbox.pack_start(button, True, True, 0)
 
-        #FIXME: quit pause button??
-        #button = hildon.Button(fhsize, horbtn)
-        #button.set_label("Pause")
-        #img = gtk.Image()
-        #img.set_from_file(imagesdir + 'pause.png')
-        #button.set_image(img)
-        #button.connect('clicked', self.on_reset)
-        #hbox.pack_start(button, True, True, 0)
-
         button = hildon.Button(fhsize, horbtn)
-        button.set_label("Start")
         img = gtk.Image()
         img.set_from_file(imagesdir + 'play.png')
         button.set_image(img)
@@ -105,12 +94,12 @@ class Timer:
         hbox.set_homogeneous(True)
 
         button = hildon.Button(fhsize, horbtn)
-        button.set_label("Hide")
+        button.set_label(_("Hide"))
         button.connect('clicked', self.only_hide)
         hbox.pack_start(button, True, True, 0)
 
         button = hildon.Button(fhsize, horbtn)
-        button.set_label("Delete")
+        button.set_label(_("Delete"))
         button.connect('clicked', self.hide_window)
         hbox.pack_start(button, True, True, 0)
 
@@ -223,10 +212,10 @@ class Timer:
         event.alarm_time = long(time.time())
 
         action_stop, action_snooze = event.add_actions(2)
-        action_stop.label = 'Stop'
+        action_stop.label = _('Stop')
         action_stop.flags |= alarm.ACTION_WHEN_RESPONDED | alarm.ACTION_TYPE_NOP
 
-        action_snooze.label = 'Snooze'
+        action_snooze.label = _('Snooze')
         action_snooze.flags |= alarm.ACTION_WHEN_RESPONDED | alarm.ACTION_TYPE_SNOOZE
 
         try:
